<?php

class church_Announcements_Slider_Widget extends WP_Widget {

	/**
	 * Sets up the widgets name etc
	 */
	public function __construct() {
		$widget_ops = array( 
			'classname' => 'church_announcements_slider_widget',
			'description' => 'Widget for displaying the church announcements in a slider',
		);
		parent::__construct( 'church_announcements_slider_widget', 'Church Announcements Slider Widget', $widget_ops );
	}

	/**
	 * Outputs the content of the widget
	 *
	 * @param array $args
	 * @param array $instance
	 */
	public function widget( $args, $instance ) {
		// outputs the content of the widget
        extract( $args );
        $title = apply_filters( 'widget_title', $instance[ 'title' ] );
        $animateIn = $instance[ 'animateIn' ];
        $animateOut = $instance[ 'animateOut' ];
        $fadetime = $instance[ 'fadetime' ];
        $slidetime = $instance[ 'slidetime' ];
        // The Query
        $the_query = new WP_Query( array(
            'post_type'		=> 'church_announcements',
            'post_per_page'	=> 5,
            'orderby'		=> 'date',
            'order'			=> 'DESC',
        ) );
        echo $before_widget;
        if ( $title ) {
            echo $before_title . $title . $after_title;
        }
        if( have_posts( $the_query ) ) {
            echo '<div id="main-slider" class="liquid-slider">';
            while ( $the_query->have_posts() ) : $the_query->the_post(); ?>

                    <div class="announcement-slide">
                      <h3><?php the_title(); ?></h3>

                      <?php the_content(); ?>
                    </div>

                <?php endwhile; ?>
                </div>
        <?php
            echo "<script>
                jQuery(function($) {
                  $('#main-slider').liquidSlider({
                    autoHeight: false,
                    autoSlide: true,
                    slideEaseFunction:'animate.css',
                    animateIn: '$animateIn',
                    animateOut: '$animateOut',
                    fadeInDuration: $fadetime,
                    fadeOutDuration: $fadetime,
                    autoSlideInterval: $slidetime,
                  });
                });
            </script>";

        }
        wp_reset_postdata();
        echo $after_widget;
	}

	/**
	 * Outputs the options form on admin
	 *
	 * @param array $instance The widget options
	 */
	public function form( $instance ) {
		// outputs the options form on admin
        // Set widget defaults
        $defaults = array(
            'title'         => '',
            'animateIn'     => '',
            'animateOut'    => '',
            'fadetime'      => 500,
            'slidetime'     => 6000,
        );
        // Parse current settings with defaults
        extract( wp_parse_args( ( array ) $instance, $defaults ) );
        ?>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id( 'title' )); ?>">Title</label>
            <input class="widefat" type="text" id="<?php echo esc_attr($this->get_field_id( 'title' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'title' )); ?>" value="<?php echo esc_attr( $title ); ?>">
        </p>
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'animateIn' ) ); ?>"><?php _e( 'animateIn', 'text_domain' ); ?></label>
            <select class="widefat" name="<?php echo $this->get_field_name( 'animateIn' ); ?>" id="<?php echo $this->get_field_id( 'animateIn' ); ?>">
                <?php
                    $options_animatein = array(
                        ''              => __( 'Choose a transition', 'text_domain' ),
                        'fadeIn'    => __( 'fadeIn', 'text_domain' ),
                        'fadeInUp'    => __( 'fadeInUp', 'text_domain' ),
                        'fadeInDown'    => __( 'fadeInDown', 'text_domain' ),
                        'fadeInLeft'    => __( 'fadeInLeft', 'text_domain' ),
                        'fadeInRight'    => __( 'fadeInRight', 'text_domain' ),
                        'fadeInLeftBig'    => __( 'fadeInLeftBig', 'text_domain' ),
                        'fadeInRightBig'    => __( 'fadeInRightBig', 'text_domain' ),
                        'bounceIn'    => __( 'bounceIn', 'text_domain' ),
                        'lightSpeedIn'    => __( 'lightSpeedIn', 'text_domain' ),
                    );
                    // Loop through options and add each one to the select dropdown
                    foreach( $options_animatein as $key => $name ){
                        echo '<option value="'. esc_attr( $key ) .'" id="'. esc_attr( $key ) .'" '. selected( $instance[ 'animateIn' ], $key ) .'>'. $name .'</option>';
                    }

                ?>
            </select>
        </p>
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'animateOut' ) ); ?>"><?php _e( 'animateOut', 'text_domain' ); ?></label>
            <select class="widefat" name="<?php echo $this->get_field_name( 'animateOut' ); ?>" id="<?php echo $this->get_field_id( 'animateOut' ); ?>">
                <?php
                    $options_animateout = array(
                        ''              => __( 'Choose a transition', 'text_domain' ),
                        'fadeOut'    => __( 'fadeOut', 'text_domain' ),
                        'fadeOutUp'    => __( 'fadeOutUp', 'text_domain' ),
                        'fadeOutDown'    => __( 'fadeOutDown', 'text_domain' ),
                        'fadeOutLeft'    => __( 'fadeOutLeft', 'text_domain' ),
                        'fadeOutRight'    => __( 'fadeOutRight', 'text_domain' ),
                        'fadeOutLeftBig'    => __( 'fadeOutLeftBig', 'text_domain' ),
                        'fadeOutRightBig'    => __( 'fadeOutRightBig', 'text_domain' ),
                        'bounceOut'    => __( 'bounceOut', 'text_domain' ),
                        'lightSpeedOut'    => __( 'lightSpeedOut', 'text_domain' ),
                    );
                    // Loop through options and add each one to the select dropdown
                    foreach( $options_animateout as $key => $name ){
                        echo '<option value="'. esc_attr( $key ) .'" id="'. esc_attr( $key ) .'" '. selected( $instance[ 'animateOut' ], $key, false ) .'>'. $name .'</option>';
                    }
                ?>
            </select>
        </p>
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'fadetime' ) ); ?>"><?php _e( 'Transition Time in milliseconds', 'text_domain' ); ?></label>
            <input type="number" class="widefat" id="<?php echo esc_attr($this->get_field_id( 'fadetime' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'fadetime' )); ?>" value="<?php echo esc_attr( $fadetime ); ?>">
        </p>
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'slidetime' ) ); ?>"><?php _e( 'Slide Hold Time in milliseconds', 'text_domain' ); ?></label>
            <input type="number" class="widefat" id="<?php echo esc_attr($this->get_field_id( 'slidetime' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'slidetime' )); ?>" value="<?php echo esc_attr( $slidetime ); ?>">
        </p>
        <?php
	}

	/**
	 * Processing widget options on save
	 *
	 * @param array $new_instance The new options
	 * @param array $old_instance The previous options
	 *
	 * @return array
	 */
	public function update( $new_instance, $old_instance ) {
		// processes widget options to be saved
        $instance = $old_instance;
        $instance[ 'title' ] = strip_tags( $new_instance[ 'title' ] );
        $instance[ 'animateIn' ] = strip_tags( $new_instance[ 'animateIn' ] );
        $instance[ 'animateOut' ] = strip_tags( $new_instance[ 'animateOut' ] );
        $instance[ 'fadetime' ] = strip_tags( $new_instance[ 'fadetime' ] );
        $instance[ 'slidetime' ] = strip_tags( $new_instance[ 'slidetime' ] );
        return $instance;
	}
}

add_action( 'widgets_init', function(){
	register_widget( 'church_Announcements_Slider_Widget' );
});