<?php

class church_Events_Widget extends WP_Widget {

	/**
	 * Sets up the widgets name etc
	 */
	public function __construct() {
		$widget_ops = array( 
			'classname' => 'church_events_widget',
			'description' => 'Widget for displaying the church events',
		);
		parent::__construct( 'church_events_widget', 'Church Events Widget', $widget_ops );
	}

	/**
	 * Outputs the content of the widget
	 *
	 * @param array $args
	 * @param array $instance
	 */
	public function widget( $args, $instance ) {
		// outputs the content of the widget
        extract( $args );
        $title = apply_filters( 'widget_title', $instance[ 'title' ] );
        // The Query
        $loop = new WP_Query( array(
            'post_type'		=> 'church_events',
            'orderby'		=> 'date',
            'order'			=> 'DESC',
        ) );
        echo $before_widget;
        if ( $title ) {
            echo $before_title . $title . $after_title;
        }
        ?>

        <!--  The Loop -->
        <?php if ( $loop->have_posts() ) : while ( $loop->have_posts() ) : $loop->the_post(); ?>
                <?php
                    // Set durrent date to central time
                    // GMT - 3600 * # hours difference
                    $currentdate = date("Ymd", time()-(25200));
                    // Get date from expiration custom field
                    $expirationdate = get_field( 'church_event_expiration' );

                    if ( ! $expirationdate ) {
                        $expirestring = '30001212'; // Set future date to posts without expiration date
                    } else {
                        $expirestring = $expirationdate;
                    }
                    if ( $expirestring > $currentdate ) {
                    // Get custom field values for the event
                    $contact_name = !empty(get_field( 'church_event_contact_name' )) ? get_field( 'church_event_contact_name' ) : '';
                    $contact_number = !empty(get_field( 'church_event_contact_number' )) ? get_field( 'church_event_contact_number' ) : '';
                    $contact_name_2 = !empty(get_field( 'church_second_contact_name' )) ? get_field( 'church_second_contact_name' ) : '';
                    $contact_number_2 = !empty(get_field( 'church_second_contact_number' )) ? get_field( 'church_second_contact_number' ) : '';
                    $start_date =   !empty(get_field( 'church_event_start_date' )) ? get_field( 'church_event_start_date' ) : '';
                    $new_start_date = date_create_from_format('Ymd', $start_date);
                    $end_date =   !empty(get_field( 'church_event_end_date' )) ? get_field( 'church_event_end_date' ) : '';
                    $new_end_date = date_create_from_format('Ymd', $end_date);
                ?>

                <article class="post">
                    <header>
                        <h3 class="event-title"><?php the_title(); ?></h3>
                        <!-- Output the start and end dates-->
                        <?php if( !empty( $start_date ) ): ?>
                            <?php echo date_format( $new_start_date, 'M d' );
                            if( !empty( $end_date ) ): ?>
                                &nbsp;to&nbsp;<?php echo date_format( $new_end_date, 'M d' );
                            endif;
                        endif; ?>
                        <!-- Output the start and end times-->
                       <?php if( !empty( get_field( 'church_event_start_time' ) ) ): ?>
                            &nbsp;at&nbsp;<?php the_field( 'church_event_start_time' );
                            if( !empty( get_field( 'church_event_end_time' ) ) ): ?>
                                &nbsp;to&nbsp;<?php the_field( 'church_event_end_time' );
                            endif;
                        endif; ?>
                        <!-- Output the location-->
                        <?php if( get_field( 'church_event_location' ) ): ?>
                            <br>Location:&nbsp;<?php the_field( 'church_event_location' );
                        endif; ?>
                    </header>
                    <div class="post-content">
                        <p><?php the_content(); ?></p>
                    </div><!-- post-content -->
                    <?php
                        if( !empty( $contact_name ) ) { ?>
                            <div class="text-center contact">
                                <p>For more information contact: <a href="tel:<?php echo $contact_number; ?>"><?php echo $contact_name; ?></a>
                                <?php if( !empty( $contact_name_2 ) ) { ?>
                                &nbsp;or&nbsp; <a href="tel:<?php echo $contact_number_2; ?>"><?php echo $contact_name_2; ?></a>
                                 <?php } ?></p>
                            </div><?php
                        }
                    ?>
                    
                </article>

        <?php }
            endwhile;
            endif;
            wp_reset_query();
        
        echo $after_widget;
	}

	/**
	 * Outputs the options form on admin
	 *
	 * @param array $instance The widget options
	 */
	public function form( $instance ) {
		// outputs the options form on admin
        
        // Set widget defaults
        $defaults = array(
            'title'     => '',
        );
        // Parse current settings with defaults
        extract( wp_parse_args( ( array ) $instance, $defaults ) );
        ?>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id( 'title' )); ?>">Title</label>
            <input class="widefat" type="text" id="<?php echo esc_attr($this->get_field_id( 'title' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'title' )); ?>" value="<?php echo esc_attr( $title ); ?>">
        </p>
        
        <?php
	}

	/**
	 * Processing widget options on save
	 *
	 * @param array $new_instance The new options
	 * @param array $old_instance The previous options
	 *
	 * @return array
	 */
	public function update( $new_instance, $old_instance ) {
		// processes widget options to be saved
        $instance = $old_instance;
        $instance[ 'title' ] = strip_tags( $new_instance[ 'title' ] );
        return $instance;
	}
}

add_action( 'widgets_init', function(){
	register_widget( 'church_Events_Widget' );
});